@@ -8,6 +8,7 @@ use crate::tools::{IntoIteratorOfSameType, IntoNonZeroArray};
 
 use super::{Alias, Column};
 
+/// Expression and things that can be converted into one
 #[derive(Debug, Clone, Eq, PartialEq)]
 pub struct Expression(String);
 
@@ -29,12 +30,36 @@ impl From<f32> for Expression {
     }
 }
 
+impl From<f64> for Expression {
+    fn from(value: f64) -> Self {
+        Expression(value.to_string())
+    }
+}
+
+impl From<i32> for Expression {
+    fn from(value: i32) -> Self {
+        Expression(value.to_string())
+    }
+}
+
+impl From<i64> for Expression {
+    fn from(value: i64) -> Self {
+        Expression(value.to_string())
+    }
+}
+
 impl From<u32> for Expression {
     fn from(value: u32) -> Self {
         Expression(value.to_string())
     }
 }
 
+impl From<u64> for Expression {
+    fn from(value: u64) -> Self {
+        Expression(value.to_string())
+    }
+}
+
 impl From<Column> for Expression {
     fn from(value: Column) -> Self {
         Expression(value.to_string())
