@@ -1,11 +1,15 @@
+//! Specific query related functions, types and traits.
+//!
+//! Most likely you want documentation for the [main module][`crate::postgres`].
+
 mod delete_from;
 mod insert_into;
 mod select;
 mod update;
 
 pub use delete_from::{delete_from, DeleteFrom};
-pub use insert_into::{insert_into, BareInsertInto, InsertInto, Values};
-pub use select::{select, Joinable, Orderable, Select};
+pub use insert_into::{insert_into, BareInsertInto, InsertInto, InsertIntoColumnsBuilder, Values};
+pub use select::{select, FromItem, Joinable, OrderBy, Orderable, Select};
 pub use update::{update, BareUpdate, Update};
 
 pub(crate) use delete_from::delete_from_with;
