@@ -16,6 +16,64 @@ pub use from_item::FromItem;
 pub use join::Joinable;
 pub use order_by::{OrderBy, Orderable};
 
+/// Create a new `SELECT` statement with given expressions.
+///
+/// Returns a [`Select`] structure that allows adding additional clauses. Call `to_string` to finalize and get SQL.
+///
+/// # Supported clauses
+///
+/// | Clause        | Method                               |
+/// |---------------|--------------------------------------|
+/// | `ALL`         | [`from`][Select::from]               |
+/// | `DISTINCT`    | [`distinct`][Select::distinct]       |
+/// | `DISTINCT ON` | [`distinct_on`][Select::distinct_on] |
+/// | `FROM`        | [`from`][Select::from]               |
+/// | `WHERE`       | [`where_`][Select::where_]           |
+/// | `GROUP BY`    | [`group_by`][Select::group_by]       |
+/// | `HAVING`      | [`having`][Select::having]           |
+/// | `ORDER BY`    | [`order_by`][Select::order_by]       |
+/// | `LIMIT`       | [`limit`][Select::limit]             |
+/// | `OFFSET`      | [`offset`][Select::offset]           |
+///
+/// # Specifying a `WITH` clause
+///
+/// To create a `SELECT` statement with a `WITH` clause, start with [`with`][crate::postgres::with] instead of this function.
+///
+/// # Useful traits to import
+///
+/// - [`Orderable`][crate::postgres::Orderable] to easily stick `DESC`/`ASC`/etc. on strings
+/// - [`Joinable`][crate::postgres::Joinable] to easily create joins from string table names
+/// - [`Aliasable`][crate::postgres::Aliasable] to easily make `x AS y` aliases for columns and such
+///
+/// # Examples
+///
+/// ```
+/// use scooby::postgres::select;
+///
+/// let sql = select("1 + 1").to_string();
+///
+/// assert_eq!(sql, "SELECT 1 + 1")
+/// ```
+///
+/// ```
+/// use scooby::postgres::{select, Joinable, Orderable, Aliasable};
+///
+/// let sql = select(("country.name".as_("name"), "COUNT(*)".as_("count")))
+///     .from(
+///         "Country"
+///             .as_("country")
+///             .inner_join("City".as_("city"))
+///             .on("city.country_id = country.id"),
+///     )
+///     .where_("city.population > 1000000")
+///     .group_by("country.name")
+///     .order_by("count".desc())
+///     .limit(10)
+///     .to_string();
+///
+/// assert_eq!(sql, "SELECT country.name AS name, COUNT(*) AS count FROM Country AS country INNER JOIN City AS city ON city.country_id = country.id WHERE city.population > 1000000 GROUP BY country.name ORDER BY count DESC LIMIT 10");
+/// ```
+
 pub fn select(expressions: impl IntoIteratorOfSameType<Expression>) -> Select {
     Select {
         expressions: expressions.into_some_iter().collect(),
@@ -31,6 +89,11 @@ pub(crate) fn select_with(expressions: Vec<Expression>, with_clause: WithClause)
     }
 }
 
+/// `SELECT` statement, possibly with additional clauses.
+///
+/// Finalize and turn into `String` by calling `to_string`.
+///
+/// See [`select`] docs for more details and examples.
 #[must_use = "Making a SELECT statement without using it is pointless"]
 #[derive(Default, Debug, Clone)]
 pub struct Select {
@@ -47,60 +110,199 @@ pub struct Select {
 }
 
 impl Select {
-    pub fn new() -> Self {
-        Default::default()
-    }
-
+    /// Add more expressions to be selected
+    ///
+    /// ```
+    /// use scooby::postgres::select;
+    ///
+    /// let sql = select(("id", "name"))
+    ///     .from("Person")
+    ///     .and_select("age")
+    ///     .and_select(("occupation_id", "city_id"))
+    ///     .to_string();
+    ///
+    /// assert_eq!(sql, "SELECT id, name, age, occupation_id, city_id FROM Person");
+    /// ```
     pub fn and_select(mut self, expressions: impl IntoIteratorOfSameType<Expression>) -> Self {
         self.expressions.extend(expressions.into_some_iter());
         self
     }
 
+    /// Explicitly specify `SELECT ALL`, i.e. non-distinct query
+    ///
+    /// ```
+    /// use scooby::postgres::select;
+    /// let sql = select("*").all().from("City").to_string();
+    /// assert_eq!(sql, "SELECT ALL * FROM City");
+    /// ```
     pub fn all(mut self) -> Self {
         self.distinct = Some(Distinct::All);
         self
     }
 
+    /// Set a simple `DISTINCT` clause
+    ///
+    /// ```
+    /// use scooby::postgres::select;
+    /// let sql = select("*").distinct().from("City").to_string();
+    /// assert_eq!(sql, "SELECT DISTINCT * FROM City");
+    /// ```
     pub fn distinct(mut self) -> Self {
         self.distinct = Some(Distinct::Distinct);
         self
     }
 
+    /// Set a `DISTINCT ON (...)` clause
+    ///
+    /// ```
+    /// use scooby::postgres::select;
+    /// let sql = select("*").distinct_on("id").from("City").to_string();
+    /// assert_eq!(sql, "SELECT DISTINCT ON (id) * FROM City");
+    /// ```
     pub fn distinct_on(mut self, expressions: impl IntoIteratorOfSameType<Expression>) -> Self {
         self.distinct = Some(Distinct::DistinctOn(expressions.into_some_iter().collect()));
         self
     }
 
+    /// Set or add more items in a `FROM` clause
+    ///
+    /// Import [`Joinable`][crate::postgres::Joinable] for convenient joins.
+    ///
+    /// You can pass subselects as well, so long as you make sure they're aliased.
+    ///
+    /// ```
+    /// use scooby::postgres::select;
+    /// let sql = select("*").from("City").from(("Other", "Third")).to_string();
+    /// assert_eq!(sql, "SELECT * FROM City, Other, Third");
+    /// ```
+    ///
+    /// ```
+    /// use scooby::postgres::{select, Joinable};
+    ///
+    /// let sql = select("col1")
+    ///     .from(
+    ///         "Person p"
+    ///             .inner_join("City c")
+    ///             .on("c.id = p.city_id")
+    ///             .left_join("Belonging b")
+    ///             .on("p.id = b.person_id"),
+    ///     )
+    ///     .to_string();
+    ///
+    /// assert_eq!(sql, "SELECT col1 FROM Person p INNER JOIN City c ON c.id = p.city_id LEFT JOIN Belonging b ON p.id = b.person_id");
+    /// ```
+    ///
+    /// ```
+    /// use scooby::postgres::{select, Aliasable};
+    ///
+    /// let sql = select("*")
+    ///     .from(select("id").from("City").as_("x"))
+    ///     .to_string();
+    ///
+    /// assert_eq!(sql, "SELECT * FROM (SELECT id FROM City) AS x");
+    /// ```
     pub fn from(mut self, from: impl IntoIteratorOfSameType<FromItem>) -> Self {
         self.from.extend(from.into_some_iter());
         self
     }
 
+    /// Add one or more `WHERE` conditions, `AND`'ed together with themselves and existing conditions.
+    ///
+    /// ```
+    /// use scooby::postgres::select;
+    ///
+    /// let sql = select("col1")
+    ///     .from("Dummy")
+    ///     .where_(("x > 1", "y > 1"))
+    ///     .where_("z > 1")
+    ///     .to_string();
+    ///
+    /// assert_eq!(sql, "SELECT col1 FROM Dummy WHERE x > 1 AND y > 1 AND z > 1");
+    /// ```
     pub fn where_(mut self, conditions: impl IntoIteratorOfSameType<Condition>) -> Self {
         self.where_.extend(conditions.into_some_iter());
         self
     }
 
+    /// Add one or more expressions in a `GROUP BY` clause
+    ///
+    /// ```
+    /// use scooby::postgres::select;
+    ///
+    /// let sql = select(("country_id", "COUNT(*)"))
+    ///     .from("City")
+    ///     .group_by("country_id")
+    ///     .to_string();
+    ///
+    /// assert_eq!(sql, "SELECT country_id, COUNT(*) FROM City GROUP BY country_id");
+    /// ```
     pub fn group_by(mut self, groupings: impl IntoIteratorOfSameType<Expression>) -> Self {
         self.group_by.extend(groupings.into_some_iter());
         self
     }
 
+    /// Add one or more expressions in a `HAVING` clause
+    ///
+    /// ```
+    /// use scooby::postgres::select;
+    ///
+    /// let sql = select(("country_id", "COUNT(*)"))
+    ///     .from("City")
+    ///     .group_by("country_id")
+    ///     .having("COUNT(*) > 10000")
+    ///     .to_string();
+    ///
+    /// assert_eq!(sql, "SELECT country_id, COUNT(*) FROM City GROUP BY country_id HAVING COUNT(*) > 10000");
+    /// ```
     pub fn having(mut self, conditions: impl IntoIteratorOfSameType<Condition>) -> Self {
         self.having.extend(conditions.into_some_iter());
         self
     }
 
+    /// Set or add more sort expressions in an `ORDER BY` clause.
+    ///
+    /// Import [`Orderable`][crate::postgres::Orderable] for convenient order specifications.
+    ///
+    /// ```
+    /// use scooby::postgres::select;
+    /// let sql = select("*").from("City").order_by("id").to_string();
+    /// assert_eq!(sql, "SELECT * FROM City ORDER BY id");
+    /// ```
+    ///
+    /// ```
+    /// use scooby::postgres::{select, Orderable};
+    ///
+    /// let sql = select("*")
+    ///     .from("City")
+    ///     .order_by(("last_modified".desc(), "id".desc()))
+    ///     .to_string();
+    ///
+    /// assert_eq!(sql, "SELECT * FROM City ORDER BY last_modified DESC, id DESC");
+    /// ```
     pub fn order_by(mut self, order_bys: impl IntoIteratorOfSameType<OrderBy>) -> Self {
         self.order_by.extend(order_bys.into_some_iter());
         self
     }
 
+    /// Set a `LIMIT` clause
+    ///
+    /// ```
+    /// use scooby::postgres::select;
+    /// let sql = select("*").from("City").limit(10).to_string();
+    /// assert_eq!(sql, "SELECT * FROM City LIMIT 10");
+    /// ```
     pub fn limit(mut self, n: u64) -> Self {
         self.limit = Some(n);
         self
     }
 
+    /// Set an `OFFSET` clause
+    ///
+    /// ```
+    /// use scooby::postgres::select;
+    /// let sql = select("*").from("City").offset(10).to_string();
+    /// assert_eq!(sql, "SELECT * FROM City OFFSET 10");
+    /// ```
     pub fn offset(mut self, n: u64) -> Self {
         self.offset = Some(n);
         self
@@ -489,11 +691,11 @@ mod tests {
                     .on("city.country_id = country.id"),
             )
             .where_("city.population > 1000000")
-            .group_by("country.id")
+            .group_by("country.name")
             .order_by("count".desc())
             .limit(10)
             .to_string();
 
-        assert_correct_postgresql(&sql, "SELECT country.name AS name, COUNT(*) AS count FROM Country AS country INNER JOIN City AS city ON city.country_id = country.id WHERE city.population > 1000000 GROUP BY country.id ORDER BY count DESC LIMIT 10");
+        assert_correct_postgresql(&sql, "SELECT country.name AS name, COUNT(*) AS count FROM Country AS country INNER JOIN City AS city ON city.country_id = country.id WHERE city.population > 1000000 GROUP BY country.name ORDER BY count DESC LIMIT 10");
     }
 }
